# ifndef yyIndependence
# define yyIndependence

# if defined __STDC__ | defined __cplusplus
# define ARGS(parameters)	parameters
# else
# define ARGS(parameters)	()
# endif

# ifndef rbool
# define rbool char
# endif

# include "Tree.h"
# include "Definitions.h"


extern void (* Independence_Exit) ARGS ((void));

extern void CheckIndependence ARGS ((tTree t));

extern void BeginIndependence ARGS ((void));
extern void CloseIndependence ARGS ((void));

# endif
